@@ -141,6 +141,16 @@ class Connection(object):
             request.write(dict(ret=constants.RET_SYSTEM, error=error))
             return None
 
+        # before_first_request_func_list
+        if not self.app.got_first_request:
+            self.app.got_first_request = True
+            for func in self.app.before_first_request_func_list:
+                safe_call(func, request)
+            # 执行blueprints
+            for name, bp in self.app.blueprints.items():
+                for func in bp.before_app_first_request_func_list:
+                    safe_call(func, request)
+
         # before_request_func_list
         for func in self.app.before_request_func_list:
             safe_call(func, request)
